########################################################################
### JCR replication files 
### Descriptive statistics
### Last checked 5.6.2019
### Author: Hannah smidt

# Libraries
library(dplyr)
library(ggplot2)
library(xtable)
library(foreign)

# Clear workspace
rm(list=ls())


# Set path depending on which machine (PC) we work
if(
  Sys.info()["user"]=="hanna"){
  pathData="C:/Users/hanna/Dropbox/PC/Documents/Paper-Reconciliation Ivory Coast v3/Code/analysis/Replication files"
}else{
  pathData="Your path" # change if necessary
}
setwd(pathData)

# Load Data
load("dataForAnalysis.RData")
dat <- dataForAnalysis2


######################################
#### Create two smaller datasets #####
#### starting on Oct 2011 and Jan 2012
######################################
dat12 <- dat[dat$EVENT_MONTH>=as.Date("2012/01/01"),]
dat11 <- dat[dat$EVENT_MONTH>=as.Date("2011/10/01"),]


############################################################
## Plot spatial and temporal distribution of DV ############
############################################################
par(mfrow = c(1,1), mar=c(5.1,4.1,4.1,2.1))
dat2 <- dat12 %>% group_by(EVENT_MONTH) %>%
            dplyr::summarize(sum_civViolence = sum(civViolence, na.rm=T)
                    , sum_militiaViolenceCommunalId = sum(militiaViolenceCommunalId, na.rm=T) 
                    , sum_govRepression = sum(govRepression, na.rm=T)
                    , sum_nsaViolenceNonCommunal = sum(nsaViolenceNonCommunal, na.rm=T) )

png("./Figures/temporallDistrViolence_V2.png", height = 4, width = 4, units = "in", res = 300)
plot(x=dat2$EVENT_MONTH, y = dat2$sum_civViolence, type="l", axes = F
     , ylab = "Violent events"
     , xlab = "Time: Month/Year"
     , ylim = c(0,12), col = "red", lwd= 2 )
lines(x=dat2$EVENT_MONTH, y = dat2$sum_militiaViolenceCommunalId, col = "blue", lwd= 2, lty = 3 )
#lines(x=dat2$EVENT_MONTH, y = dat2$sum_govRepression, col = "orange", lwd= 2, lty = 2 )
#lines(x=dat2$EVENT_MONTH, y = dat2$sum_nsaViolenceNonCommunal, col = "pink", lwd= 2, lty = 4 )
axis(1, at = c( as.Date("01/01/12", "%d/%m/%y"), as.Date("01/01/13", "%d/%m/%y"),
                as.Date("01/01/14", "%d/%m/%y"), as.Date("01/01/15", "%d/%m/%y"),
                as.Date("01/01/16", "%d/%m/%y"), as.Date("01/07/16", "%d/%m/%y"))
     , label = format( c( as.Date("01/01/12", "%d/%m/%y"), as.Date("01/01/13", "%d/%m/%y"),
                          as.Date("01/01/14", "%d/%m/%y"), as.Date("01/01/15", "%d/%m/%y"),
                          as.Date("01/01/16", "%d/%m/%y"), "" ), "%m/%y") )
axis(2, at = seq(0,12,2))
legend(x=as.Date("01/06/12", "%d/%m/%y"), y=12.3, cex=0.75, title = "Communal violence by", legen = c("Civilians", "Armed groups")
       , col = c("red","blue"), lty = c(1, 3), lwd = c(2,2) )
dev.off()


####################################################################
### Temporal distribution of intergroup and training activities ####
####################################################################
dat3 <- dat11 %>% group_by(EVENT_MONTH) %>%
  dplyr::summarize( sum_intergrDialogue = sum(reconciliationPublicEvent2, na.rm=T) )

png("./Figures/temporallDistrDialogue.png", height = 4, width = 4, units = "in", res = 300)
par(mfrow = c(1,1), mar=c(5.1,4.1,4.1,2.1))
plot(x=dat3$EVENT_MONTH, y = dat3$sum_intergrDialogue, type="l", axes = F
                    , ylab = "UNOCI's dialogue activities"
                    , xlab = "Time: Month/Year"
                    , ylim = c(0,30), col = "darkgreen", lwd= 2 )
axis(1, at = c( as.Date("01/10/11", "%d/%m/%y"), as.Date("01/01/13", "%d/%m/%y"),
                                as.Date("01/01/14", "%d/%m/%y"), as.Date("01/01/15", "%d/%m/%y"),
                                as.Date("01/01/16", "%d/%m/%y"), as.Date("01/07/16", "%d/%m/%y"))
      , label = format( c( as.Date("01/10/11", "%d/%m/%y"), as.Date("01/01/13", "%d/%m/%y"),
                          as.Date("01/01/14", "%d/%m/%y"), as.Date("01/01/15", "%d/%m/%y"),
                          as.Date("01/01/16", "%d/%m/%y"), "" ), "%m/%y") )
axis(2, at = seq(0,25,5))
#legend("topright", legen = c("Intergroup dialogue"), col = c("darkgreen" ), lty = c(1), lwd = c(2) )
dev.off()


###################################################################
### Spatial distribution of training and dialogue activities ####
###################################################################

# Load map from Cote d'Ivoire
setwd(pathData)
setwd("./civ_admbnda_adm3_cntig_20160527")
map<-rgdal::readOGR(dsn = ".", layer = "civ_admbnda_adm3_cntig_20160527")
setwd(pathData)

# Summarise reconciliation events by department
dat3 <- dat11  %>% group_by(Department) %>%
  dplyr::summarize( sum_intergrDialogue = sum(reconciliationPublicEvent2, na.rm=T)) %>% ungroup %>% as.data.frame

# Get map data
map.data <- data.frame(id=rownames(map@data), Department=toupper(map@data$admin3RefN) )
  
# Merge with data from map
map.data <- merge(map.data, dat3, by="Department",all=T)
map.df   <- fortify(map)
map.df   <- merge(map.df, map.data,all=T)
map.df <-map.df[order(map.df$id,map.df$order),]

## Map of dialogues 
png("./Figures/spatialDistrDialogue.png", height = 4, width = 4, units = "in", res = 300)
ggplot(map.df,aes(x=long,y=lat,group=group)) +
  geom_polygon(aes(fill=sum_intergrDialogue, color="grey20"), color = "black") +
  scale_fill_gradient2(name = "Number of\ndialogue activities",mid="white",high="darkgreen",limits=c(0,35)) +
  coord_map()+labs(x="",y="") +
  theme_bw() +
  theme(panel.grid=element_blank(),
        panel.border=element_blank(),
        axis.text=element_blank(),
        axis.ticks=element_blank(),
        legend.title=element_text(size=10) )+
  guides(colour=FALSE) 
dev.off()


## Offices of UNOCI
Abidjan  <- c(-4.008256, 5.359952)
SanPedro  <- c( -6.642433, 4.757869)
Aboisso  <- c(-3.203076, 5.474511)
Bondoukou  <- c(-2.807864, 8.047883)
Bouake  <- c(-5.039054, 7.690466)
Duekoue <- c(-7.36246, 6.74738)
Daloa <- c(-6.439689, 6.888334)
Korhogo <- c(-5.614256, 9.466934)
Odienne <- c( -7.557223, 9.518875)
Tai <- c(-7.454016, 5.871288)
Toulepleu <- c(-8.410198, 6.579563)
Yamoussoukro <- c(-5.289343, 6.827623)
Divo <- c(-5.366667, 5.833333)
Man <- c(-7.55, 7.4)
fieldOffices <- as.data.frame( rbind(Abidjan, SanPedro, Aboisso
                                     ,Bondoukou, Bouake, Duekoue, Daloa
                                     ,Korhogo, Odienne, Tai
                                     ,Toulepleu, Yamoussoukro, Divo, Man ) )
colnames(fieldOffices) <- c("Long", "Lat")

#png("./Figures/UNOCI_FieldOffices.png", height = 4, width = 4, units = "in", res = 300)
ggplot(map.df,aes(x=long,y=lat, group=group)) +  geom_polygon(color="#2b2b2b", fill="white") +
  geom_point(data=fieldOffices, aes(x=Long, y=Lat, group = NULL),shape=15, size=4, fill="blue", color="blue" ) +
  coord_map()+labs(x="",y="") +
  theme_bw() +
  theme(panel.grid=element_blank(),
        panel.border=element_blank(),
        axis.text=element_blank(),
        axis.ticks=element_blank())+
  guides(colour=FALSE) 
#dev.off()



##########################
## Summary statistics ####
##########################

vars <- c("civViolence2"
          ,"militiaViolenceCommunalId2"
          ,"govRepression2"
          ,"nsaViolenceNonCommunal2"
          ,"reconciliationPublicEvent3Lag2"
          ,"PKOpolice" 
          ,"PKOpolice_scaled"
          ,"PKOtroops"
          ,"PKOtroops_scaled"
          ,"electionMonths"
          ,"competitiveness"
          ,"ttime_mean"
          ,"bdist1"
          ,"imr_mean"
          ,"Total"
          ,"civilAffairsHR_Int"
          ,"distOfficeForHR_geo_scaled")


dat2 <- dat12[,vars]
means <- sapply(dat2, mean, na.rm=T)
sd <- sapply(dat2, sd, na.rm=T)
min <- sapply(dat2, min, na.rm=T)
max <- sapply(dat2, max, na.rm=T)
N <- nrow(dat2[complete.cases(dat2),])

summaryStats <- as.data.frame( cbind(means, sd, min, max, N) )
colnames(summaryStats) <- c("Mean", "St. dev.", "Min", "Max", "N")
rownames(summaryStats) <- c("Communal violence by civilian groups"
                             ,"Communal violence by armed groups"
                             ,"Government violence"
                            ,"Non-communal violence by armed groups"
                             ,"UNOCI dialogue"
                             ,"Number of UN police personnel (std.)"
                             ,"Number of UN police personnel"
                            ,"Number of UN military personnel (std.)"
                            ,"Number of UN military personnel"
                             ,"Election months"
                             ,"Competitiveness"
                             ,"Travel time","Border distance","Infant mortality"
                             ,"Population size"
                            , "Civil Affairs personnel"
                            , "Travel time to field office")

addtorow <- list()
addtorow$pos <- list(-1)
addtorow$command <- paste0('\\hline\\hline\\')

summaryStats2 <- format(round(summaryStats,3), 3)

print.xtable(xtable(summaryStats2
                    , caption = "Summary statistics"
                    , label = "table:table_Stats"
                    ,align = "lrrrrr")
             , add.to.row = addtorow
             , type="latex"
             , hline.after=c(0,nrow(summaryStats),nrow(summaryStats) )
             , caption.placement = "top"
             , append = F
             , file = "./Tables/summaryStats.tex")
