************************************************************************
*** JCR replication files 
*** Main analyses
*** Last checked 4.6.2019
*** Author: Hannah smidt


version 13.0
set more off
clear

** Set working directory
cd "C:\Users\hanna\Dropbox\PC\Documents\Paper-Reconciliation Ivory Coast v3\Code\analysis\Replication files"

** Load data
use "dataForAnalysis.dta", clear

** Prepare time series
encode Department, gen(Department_num)

** Get event month into right format and drop in-war obs
format EVENT_MONTH %tdCCYY.NN.DD
keep if EVENT_MONTH >= date("01january2012", "DMY")

** Generate interactions and instrument
capture drop civilAffairsPers 
capture drop instrument
capture gen civilAffairsPers = civilAffairsHR_Int
capture gen distHQ = distOfficeForHR_geo_scaled
capture gen instrument = civilAffairsPers * distHQ 


** Beck, Katz, and Tucker 1998: binary time-series cross-section (BTSCS) with temporal dependency = grouped duration model
** Carter & Signorino 2010
gen monthsOfNoCivViolence2 = monthsOfNoCivViolence * monthsOfNoCivViolence 
gen monthsOfNoCivViolence3 = monthsOfNoCivViolence * monthsOfNoCivViolence * monthsOfNoCivViolence

gen monthsOfNoMilitiaViolencCmmnlId2 = monthsOfNoMilitiaViolencCmmnlId * monthsOfNoMilitiaViolencCmmnlId
gen monthsOfNoMilitiaViolencCmmnlId3 = monthsOfNoMilitiaViolencCmmnlId * monthsOfNoMilitiaViolencCmmnlId * monthsOfNoMilitiaViolencCmmnlId


** Generate district effect
capture drop District1-District13
capture tabulate District, gen(District)

** Add Labels
do "Replication_variableLabels"


*******************************************************************************
** Bivariate probit models of violence involving civilians
*******************************************************************************
set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/Table2_MainModel_CivViolence.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

capture drop estimate
capture drop low
capture drop high
margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
gen estimate = `b'[1,1] in 1
gen low =  `b'[5,1] in 1
gen high = `b'[6,1] in 1



** CEM
set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ) [iweight = cem_weights], robust from(coef_start) ;
#delimit cr
test instrument
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start1 = e(b)


#delimit ;
outreg2 [m] using "./Tables/Table2_MainModel_CivViolence.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 2
replace low =  `b'[5,1] in 2
replace high = `b'[6,1] in 2


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 District1-District11) [iweight=cem_weight], robust from(coef_start1) ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/Table2_MainModel_CivViolence.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 3
replace low =  `b'[5,1] in 3
replace high = `b'[6,1] in 3
capture drop x
gen x = 1 in 1
replace x = 2 in 2
replace x = 3 in 3

#delimit ;
twoway scatter estimate x, msize(large) || rcap low high x, yline(0) lcolor(gs0) color(gs0) msize(large)
xscale(range(0.5 3.5)) xlabel(1 `" "Model 1" "Without matching" "' 2 `" "Model 2" "After matching" "' 3 `" "Model 3" "After matching" "+ region dummies" "', labsize(large))
xtitle("")
yscale(range(-0.5 0.1)) ylabel(-0.5 "-0.5" -0.4 "-0.4" -0.3 "-0.3" -0.2 "-0.2" -0.1 "-0.1" 0 "0" 0.1 "0.1")
ytitle("Marginal effect of dialogues" " " , size(large))
scheme(stmono) graphregion(fcolor(white)) lstyle(none)
legend(off);
#delimit cr



*******************************************************************************
** Bivariate probit models of violence involving militia groups
*******************************************************************************
set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 ), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start = e(b)
margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force level(90)
tempname b
matrix `b' = r(table)
matrix list `b'
capture drop estimate low high
gen estimate = `b'[1,1] in 1
gen low =  `b'[5,1] in 1
gen high = `b'[6,1] in 1

#delimit ;
outreg2 [m] using "./Tables/Table3_MainModel_MilitiaViolence.doc", replace
symbol(**, *, +) ctitle("UN") dec(4) label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



** CEM
set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId  monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 ) [iweight = cem_weights], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start2 = e(b)

#delimit ;
outreg2 [m] using "./Tables/Table3_MainModel_MilitiaViolence.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force level(90)
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 2
replace low =  `b'[5,1] in 2
replace high = `b'[6,1] in 2


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 District1-District11) [iweight = cem_weights], robust from(coef_start2) nrtol(0.0001);
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]
capture gen sample = e(sample)

#delimit ;
outreg2 [m] using "./Tables/Table3_MainModel_MilitiaViolence.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force level(90)
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 3
replace low =  `b'[5,1] in 3
replace high = `b'[6,1] in 3
capture drop x
gen x = 1 in 1
replace x = 2 in 2
replace x = 3 in 3

#delimit ;
twoway scatter estimate x, msize(large) || rcap low high x, yline(0) lcolor(gs0) color(gs0) msize(large)
xscale(range(0.5 3.5)) xlabel(1 `" "Model 4" "Without matching" "' 2 `" "Model 5" "After matching" "' 3 `" "Model 6" "After matching" "+ region dummies" "', labsize(large))
xtitle("")
yscale(range(-0.6 0.1)) ylabel(-0.5 "-0.5" -0.4 "-0.4" -0.3 "-0.3" -0.2 "-0.2" -0.1 "-0.1" 0 "0" 0.1 "0.1")
ytitle("Marginal effect of dialogues" " " , size(large))
scheme(stmono) graphregion(fcolor(white)) lstyle(none)
legend(off);
#delimit cr

exit


