########################################################################
### JCR replication files 
### Map violent events from ACLED
### Last checked 5.6.2019
### Author: Hannah smidt


rm(list=ls())
library(readxl)
library(dplyr)

## Load data
# Set path depending on which machine (PC) we work
if(
  Sys.info()["user"]=="hanna"){
  pathData="C:/Users/hanna/Dropbox/PC/Documents/Paper-Reconciliation Ivory Coast v3/Code/analysis/Replication files"
}else{
  pathData="Your path"
}


setwd(pathData)
dataCDI<-read_xlsx("Ivory-Coast.xlsx")

## Pick only observations from 2009
dataCDI2<- dataCDI[dataCDI$YEAR>2008,]
dataCDI2<- dataCDI2[dataCDI2$ADMIN2!="Abidjan",]
dataCDI2 <- dataCDI2[!is.na(dataCDI2$LONGITUDE),]


#################################################
## Create identifier for events of interest #####
#################################################

### Drop non-violent events
unique(dataCDI2$EVENT_TYPE)
unique(dataCDI2$INTERACTION[dataCDI2$YEAR>=2012])[order(unique(dataCDI2$INTERACTION[dataCDI2$YEAR>=2012]))]
dataCDI2 <- dataCDI2[which(dataCDI2$EVENT_TYPE!="Remote violence" & 
                             dataCDI2$EVENT_TYPE!="Strategic development" &
                             dataCDI2$EVENT_TYPE!="Non-violent transfer of territory" &
                             dataCDI2$INTERACTION!=60 &
                             dataCDI2$INTERACTION!=66 &
                             dataCDI2$INTERACTION!=67 &
                             dataCDI2$INTERACTION!=68 &
                             dataCDI2$INTERACTION!=80),]

## All violent events
dataCDI2$violence <- 1


##########################################
#### Violence by groups of civilians #####
##########################################

## Events involving rioters
dataCDI2$riots <- 0
dataCDI2$riots[which(dataCDI2$INTER1==5 | dataCDI2$INTER2==5)] <- 1
dataCDI2$riots[grepl("Two gay men", dataCDI2$NOTES)] <-0
dataCDI2$riots[grepl("Members of the RDR violently prevented the President of the FPI from entering Doropo", dataCDI2$NOTES)] <-1
dataCDI2$riots[grepl("Members of the RDR destroyed during the night equipment installed by local FPI leaders in a public square for an event that was to be held by President Affi", dataCDI2$NOTES)] <-1

## Events by "comunal militias groups", which are basically groups of local civilians
dataCDI2$communViolence <- 0
dataCDI2$communViolence[which(dataCDI2$INTER1==4 | dataCDI2$INTER2==4)] <- 1
dataCDI2$communViolence[grepl("Dozo militia attacks civilians", dataCDI2$NOTES)] <- 0
dataCDI2$communViolence[grepl("A vigilante mob killed a man wrongly suspected of kidnapping", dataCDI2$NOTES)] <-0
dataCDI2$communViolence[grepl("Communal clashes in the town of Vavoua related to leadership led to several injuries", dataCDI2$NOTES)] <-1
dataCDI2$communViolence[grepl("Violent clash between two communities injuring a number of youth", dataCDI2$NOTES)] <-1
dataCDI2$communViolence[grepl("Administrative and Security forces intervened to restore order after communal clashes in Tiametolo between the Lobi and Fulani communities", dataCDI2$NOTES)] <-1
dataCDI2$communViolence[grep("Clashes between political rivals", dataCDI2$NOTES)] <-1


# Events involving civilians (rioters and ethnic local militias)
dataCDI2$civViolence <- 0
dataCDI2$civViolence[which(dataCDI2$riots == 1 | dataCDI2$communViolence == 1)] <- 1


#######################################
#### Violence by government agents ####
#######################################

## Events of repression against unarmed and non-violent civilians and demonstrators
dataCDI2$govRepression <- 0
dataCDI2$govRepression[which(dataCDI2$INTERACTION==16 | dataCDI2$INTERACTION==17)] <-1
dataCDI2$govRepression[which(dataCDI2$INTERACTION==11 | dataCDI2$INTERACTION==12)] <-1



#####################################################
## Violence by militias with ties to communities ####
#####################################################

## Events by armed groups that rely on civilian support and are somehow related to communal identity
dataCDI2$militiaViolence<- 0
dataCDI2$militiaViolence [dataCDI2$INTER1==3 | dataCDI2$INTER2==3 | dataCDI2$INTER1==2 | dataCDI2$INTER2==2] <- 1

## Additional events added:
dataCDI2$militiaViolence[grepl("Dozo militia attacks civilians", dataCDI2$NOTES)] <- 1
dataCDI2$militiaViolence[grepl("Gunmen from Liberia carried out an attack against a village in western Cte dIvoire, near Toulepleu",dataCDI2$NOTES)] <- 1

## Events deleted, because already coded as riots or communal violence by groups of civilians:
dataCDI2$militiaViolence[grep("Members of the RDR violently prevented the President of the FPI from entering Doropo", dataCDI2$NOTES)] <-0
dataCDI2$militiaViolence[grep("Members of the RDR destroyed during the night equipment installed by local FPI leaders in a public square for an event that was to be held by President Affi", dataCDI2$NOTES)] <-0
dataCDI2$militiaViolence[grep("Communal clashes in the town of Vavoua related to leadership led to several injuries", dataCDI2$NOTES)] <-0
dataCDI2$militiaViolence[grep("Clashes between political rivals", dataCDI2$NOTES)] <-0

## Events deleted, because criminal violence
dataCDI2$militiaViolence[grepl("bandit|Bandit", dataCDI2$NOTES)] <- 0
dataCDI2$militiaViolence[grepl("coupeur", dataCDI2$NOTES)] <- 0
dataCDI2$militiaViolence[grep("Pirates seized a Panamanian vessel", dataCDI2$NOTES)] <- 0
dataCDI2$militiaViolence[grep("Armed men robbed two Senegalese boutique owners in Yamoussoukro, killing one", dataCDI2$NOTES)] <-0
dataCDI2$militiaViolence[grep("A bus of soccer players has been attacked and robbed, with one killed and 23 injured, on the road between Duekou and Bangolo, and between the villages of Beoue and Binao", dataCDI2$NOTES)] <-0
dataCDI2$militiaViolence[grep("Two Ivorian gendarmes were seriously injured after a large group of illegal miners attacked a police patrol", dataCDI2$NOTES)] <- 0
# Criminal violence: Attack on NGO (not related to communal conflict: http://koaci.com/m/articles-89662-i.html)
dataCDI2$militiaViolence[grepl("Armed attack on a humanitarian convoy transporting supplies on behalf of a non-governmental organization", dataCDI2$NOTES)] <- 0
# Criminal violence: Attack on school director (not related to communal conflict; see http://news.abidjan.net/h/519384.html)
dataCDI2$militiaViolence[grepl("The director of a public primary school was killed with machetes by unidentified assailants in his home. The motive for the incident was unclear and nothing was taken.", dataCDI2$NOTES)] <- 0

## Events deleted, because attacks by AQIM
dataCDI2$militiaViolence[grep("Authorites fought off AQIM attacking civilians at three neighboring beach resorts", dataCDI2$NOTES)] <- 0
dataCDI2$militiaViolence[grep("Between 3 - 7 AQIM gunmen stormed three hotels and nearby beaches", dataCDI2$NOTES)] <- 0

## Events deleted, because done by ex-combatants (protest)
dataCDI2$militiaViolence[grep("A convoy of the national Authority for Disarmament, Demobilization and Reintegration was attacked , resulting in the fatality of a gendarme. It has been suggested that demobilized soldiers may be behind the attack", dataCDI2$NOTES)] <-0
dataCDI2$militiaViolence[grep("Men in military uniforms attacked a police station, causing several injuries. They are believed to be demobilized soldiers.", dataCDI2$NOTES)] <-0



################################################################
## Violence by non-state actors with a communal identity 
################################################################

dataCDI2$militiaViolenceCommunalId <- 0
dataCDI2$militiaViolenceCommunalId[which( dataCDI2$INTERACTION==13) ] <- 1
dataCDI2$militiaViolenceCommunalId[grepl("Eight people were killed and ten homes", dataCDI2$NOTES)] <-1
dataCDI2$militiaViolenceCommunalId[grepl("2 civilians killed and unkown number of women raped in Guitrozon town by an militiaentified armed group", dataCDI2$NOTES)] <-1
dataCDI2$militiaViolenceCommunalId[grepl("2 killed during an attack", dataCDI2$NOTES)] <-1
dataCDI2$militiaViolenceCommunalId[grepl("An attack carried out on Thursday night", dataCDI2$NOTES)] <-1
dataCDI2$militiaViolenceCommunalId[grepl("armed men attack the residence of the public prosecutor in Oume", dataCDI2$NOTES)] <-1
dataCDI2$militiaViolenceCommunalId[grepl("4 dead people after the attack of Gregbeu Village, in Daloa Department", dataCDI2$NOTES)] <-1
dataCDI2$militiaViolenceCommunalId[grepl("An heavily armed group took in hostage an entire village", dataCDI2$NOTES)] <-1
dataCDI2$militiaViolenceCommunalId[grepl("An armed gang killed 1 person during an attack across the border from Liberia", dataCDI2$NOTES)] <-1
dataCDI2$militiaViolenceCommunalId[grepl("Gunmen from Liberia carried out an attack against a village in western Cte dIvoire, near Toulepleu",dataCDI2$NOTES)] <- 1
dataCDI2$militiaViolenceCommunalId[grepl("At least six people were injured in confrontations between two armed groups near the village",dataCDI2$NOTES)]<-1
dataCDI2$militiaViolenceCommunalId[grepl("an attack was carried out by some 300 individuals against a camp",dataCDI2$NOTES)] <-1



####################################################
### Rest of events by non-communal armed groups ####
####################################################
dataCDI2$nsaViolenceNonCommunal <- 0
dataCDI2$nsaViolenceNonCommunal[dataCDI2$govRepression==0 & dataCDI2$militiaViolence==0 & dataCDI2$civViolence==0] <- 1
dataCDI2$nsaViolenceNonCommunal[dataCDI2$INTERACTION==14] <-0 # State response to communal clash (legitmate action, not counted)


###############################################
####### Check out distribution ################
###############################################

nciv <- length( dataCDI2$violence[(dataCDI2$civViolence==1) & dataCDI2$YEAR>=2012] ) / length( dataCDI2$violence[(dataCDI2$YEAR>=2012)] )
nmil <- length( dataCDI2$violence[(dataCDI2$militiaViolence==1) & dataCDI2$YEAR>=2012] ) / length( dataCDI2$violence[(dataCDI2$YEAR>=2012)] )
nmilId <- length( dataCDI2$violence[(dataCDI2$militiaViolenceCommunalId==1) & dataCDI2$YEAR>=2012] ) / length( dataCDI2$violence[(dataCDI2$YEAR>=2012)] )
nrep <- length( dataCDI2$violence[(dataCDI2$govRepression==1) & dataCDI2$YEAR>=2012] ) / length( dataCDI2$violence[(dataCDI2$YEAR>=2012)] )
nnsa <- length( dataCDI2$violence[(dataCDI2$nsaViolenceNonCommunal ==1) & dataCDI2$YEAR>=2012] ) / length( dataCDI2$violence[(dataCDI2$YEAR>=2012)] )

length( dataCDI2$violence[(dataCDI2$militiaViolence==1 | dataCDI2$civViolence==1) & dataCDI2$YEAR>=2012] ) / length( dataCDI2$violence[(dataCDI2$YEAR>=2012)] )
## 79 percent of violent events (incl. Abidjan) covered by communal violence (incl. groups of civilians and communal violence by communal militias)

## List of identifiers that become variables
vars <- c("violence", "riots", "communViolence", "civViolence", "militiaViolence", "militiaViolenceCommunalId", "govRepression", "nsaViolenceNonCommunal")


###############################################################
## Make map before aggregating to department level ############
###############################################################

# Load map from Cote d'Ivoire
setwd("./civ_admbnda_adm3_cntig_20160527/")
map<-rgdal::readOGR(dsn = ".", layer = "civ_admbnda_adm3_cntig_20160527")
setwd(pathData)
map_poly <- sp::SpatialPolygons(map@polygons)
sp::coordinates(dataCDI2) <- ~LONGITUDE + LATITUDE

# Plot all types of violence across years
par(mfrow = c(2,3), mar=c(2,2,2,2))
for(i in 2012:2016){
  sp::plot(map_poly, main=paste0(i))
  points(dataCDI2[which(dataCDI2$civViolence==1 & dataCDI2$YEAR==i),], col="blue", pch=1, cex=2)
  points(dataCDI2[which(dataCDI2$militiaViolence==1 & dataCDI2$YEAR==i),], col="orange", pch=4, cex=2)
  points(dataCDI2[which(dataCDI2$govRepression==1 & dataCDI2$YEAR==i),], col="red", pch=2, cex=2)
  points(dataCDI2[which(dataCDI2$nsaViolenceNonCommunal==1 & dataCDI2$YEAR==i),], col="pink", pch=6, cex=2)
}
plot(x=1,y=1,type="n", axes=F)
legend("center", legend = c("Civilians", "Communal NSA", "Government", "Non-communal NSA")
       , col=c("blue", "orange", "red","pink"), pch =c(1,4,2,6), cex=0.75)

# Plot all types of violence in one plot
par(mfrow = c(1,1), mar=c(5.1,4.1,2.1,2.1))
sp::plot(map_poly, ylim = c(3.5,13), main = "")
points(dataCDI2[dataCDI2$govRepression==1,], col="orange", pch=1, cex=2)
points(dataCDI2[dataCDI2$nsaViolenceNonCommunal==1,], col="pink", pch=4, cex=2)
points(dataCDI2[dataCDI2$civViolence==1,], col="red", pch=2)
points(dataCDI2[dataCDI2$militiaViolenceCommunalId==1,], col="blue", pch=3)
par(mfrow = c(1,1), mar=c(1,1,1,1))
plot(x=1, y=1, type="n", axes=F, xlab="", ylab="")
legend(x=0.75, y=1, title = "Violent events:", legen = c("Civilians", "Militia with local ties", "Government", "Any non-state group")
       , col = c("red","blue","orange", "pink"), pch =c(2,3,1,4), cex=0.7 )

# Plot for manuscript
png("./Figures/spatialDistrViolence.png", height = 4, width = 4, units = "in", res = 300)
par(mfrow = c(1,1), mar=c(5.1,4.1,4.1,2.1))
sp::plot(map_poly, ylim = c(3.5,13), main = "")
points(dataCDI2[dataCDI2$civViolence==1,], col="red", pch=2)
points(dataCDI2[dataCDI2$militiaViolenceCommunalId==1,], col="blue", pch=3)
dev.off()

# Legend for plot for manuscript
png("./Figures/spatialDistrViolence_legend.png", height = 4, width = 4, units = "in", res = 300)
par(mfrow = c(1,1), mar=c(1,1,1,1))
plot(x=1, y=1, type="n", axes=F, xlab="", ylab="")
legend(x=0.75, y=1, title = "Communal violence by", legen = c("Civilians", "Armed groups")
       , col = c("red","blue"), pch =c(2,3), cex=0.75 )
dev.off()


########################################################
# Check out the admin unites: Departments, and change ##
########################################################
unique(dataCDI2$ADMIN3)[!unique(dataCDI2$ADMIN3) %in%  map@data$admin3RefN]
dataCDI2$ADMIN3 <- toupper( as.character(dataCDI2$ADMIN3) )
dataCDI2[grepl("MBahiakro",dataCDI2$ADMIN3),"ADMIN3"]<-"M'BAHIAKRO" # Spelling
dataCDI2[grepl("SAN-PEDRO",dataCDI2$ADMIN3),"ADMIN3"]<-"SAN PEDRO" # Spelling
dataCDI2[dataCDI2$ADMIN3=="TOUNKARATA","ADMIN3"]<-"DANANE" # Guinean village at the border of CDI and Danane Department
dataCDI2[dataCDI2$ADMIN3=="BONOUA","ADMIN3"]<-"GRAND-BASSAM" # Change name; departmental capital is Bonoua
dataCDI2[dataCDI2$ADMIN3=="NIAKARMADOUGOU", "ADMIN3"] <- "NIAKARAMANDOUGOU" # Spelling
dataCDI2[dataCDI2$ADMIN3=="KOUMASSI", "ADMIN3"] <- "ABIDJAN" # Suburb of Abidjan


##############################################
# Make into Event_DATE ADMIN3 Format #########
##############################################

dataCDI2$EVENT_MONTH <- format( as.Date(gsub("-[0-9]+$", "-01", dataCDI2$EVENT_DATE)) , "%Y-%m")

# Pick relevant variables ####
dataCDI4 <- dplyr::select(dataCDI2@data, 
                          ADMIN3,EVENT_DATE,EVENT_MONTH,
                          EVENT_TYPE,ACTOR1,ALLY_ACTOR_1,
                          ACTOR2, ALLY_ACTOR_2,NOTES,
                          vars)


# Group and create time variable 
dataCDI5 <-dataCDI4 %>% dplyr::group_by(ADMIN3, EVENT_MONTH) %>% dplyr::mutate(timevar = seq(n())) %>% ungroup

# Reshape data: IDs=ADMIN3, EVENT_DATE ####
dataCDI6 <-reshape(data.table::setDT(dataCDI5), idvar=c('ADMIN3', 'EVENT_MONTH'), 
              timevar="timevar" ,direction='wide')
# Data frame
dataCDI6 <- as.data.frame(dataCDI6)

# Aggregate by event_date and Admin
for(i in 1: length(vars)){
  dataCDI6[,vars[i]] <- apply(as.data.frame( dataCDI6[grep(paste0(vars[i],".[0-9]"),names(dataCDI6))] ), 1, function(x){ sum(na.omit(x)) } )
}

dataCDI6$NOTES <- apply(as.data.frame( dataCDI6[grep("NOTES.[0-9]",names(dataCDI6))] ), 1, function(x){ paste(x, collapse=", ") } )
dataCDI6$NOTES <- gsub(", NA","",dataCDI6$NOTES)

# Make Year and month
dataCDI6$Year <- 	as.numeric( substr(dataCDI6$EVENT_MONTH, 1,4) )
dataCDI6$Month <- as.numeric( substr(dataCDI6$EVENT_MONTH, 6,7) )

# Duplicates
ACLED<-dplyr::select(dataCDI6, ADMIN3, Year, Month, NOTES,
                     vars)

