************************************************************************
*** JCR replication files 
*** Supplementary analyses
*** Last checked 4.6.2019
*** Author: Hannah smidt


version 13.0
set more off
clear

** Set working directory
cd "C:\Users\hanna\Dropbox\PC\Documents\Paper-Reconciliation Ivory Coast v3\Code\analysis\Replication files"

** Load data
use "dataForAnalysis.dta", clear

** Prepare time series
encode Department, gen(Department_num)

** Get event month into right format and drop in-war obs
format EVENT_MONTH %tdCCYY.NN.DD
keep if EVENT_MONTH >= date("01january2012", "DMY")

** Generate interactions and instrument
capture drop civilAffairsPers 
capture drop instrument
capture gen civilAffairsPers = civilAffairsHR_Int
capture gen distHQ = distOfficeForHR_geo_scaled
capture gen instrument = civilAffairsPers * distHQ 

** Beck, Katz, and Tucker 1998: binary time-series cross-section (BTSCS) with temporal dependency = grouped duration model
** Carter & Signorino 2010
gen monthsOfNoCivViolence2 = monthsOfNoCivViolence * monthsOfNoCivViolence 
gen monthsOfNoCivViolence3 = monthsOfNoCivViolence * monthsOfNoCivViolence * monthsOfNoCivViolence
gen monthsOfNoMilitiaViolencCmmnlId2 = monthsOfNoMilitiaViolencCmmnlId * monthsOfNoMilitiaViolencCmmnlId
gen monthsOfNoMilitiaViolencCmmnlId3 = monthsOfNoMilitiaViolencCmmnlId * monthsOfNoMilitiaViolencCmmnlId * monthsOfNoMilitiaViolencCmmnlId

gen monthsOfNoGovRepression2 = monthsOfNoGovRepression*monthsOfNoGovRepression
gen monthsOfNoGovRepression3 = monthsOfNoGovRepression*monthsOfNoGovRepression*monthsOfNoGovRepression
gen monthsOfNoNsaViolenceNonCommunl2 = monthsOfNoNsaViolenceNonCommunl * monthsOfNoNsaViolenceNonCommunl
gen monthsOfNoNsaViolenceNonCommunl3 = monthsOfNoNsaViolenceNonCommunl * monthsOfNoNsaViolenceNonCommunl * monthsOfNoNsaViolenceNonCommunl

gen monthsOfNoMilitiaViolence2 = monthsOfNoMilitiaViolence * monthsOfNoMilitiaViolence
gen monthsOfNoMilitiaViolence3 = monthsOfNoMilitiaViolence * monthsOfNoMilitiaViolence * monthsOfNoMilitiaViolence


** Generate district effect
capture drop District1-District13
capture tabulate District, gen(District)

** Add Labels
do "Replication_variableLabels"



*****************************************
** Appendix B
** Test instrument for dialogue events
*****************************************

* test for condition 1
probit reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument, robust
test civilAffairsPers distHQ instrument
test instrument

est store m
estat ic
mat es_ic = r(S)

local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixB_instrument.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) ;
#delimit cr


probit reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument District1-District11, robust
test civilAffairsPers distHQ instrument
test instrument
est store m
estat ic
mat es_ic = r(S)

local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixB_instrument.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) ;
#delimit cr

quietly: probit reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled  electionMonths competitiveness ttime_mean bdist1 imr_mean Total c.civilAffairsPers##c.distHQ, robust

margins, at(distHQ = (-1.5(0.5)3.5)) asobserved dydx(civilAffairsPers) level(95)
marginsplot, recast(line) recastci(rline) title(" ") plotopts(lwidth(medthick)) ciopts(lpattern(dash dash) lwidth(medthick)) yline(0) ///
graphregion(fcolor(white)) ///
ytitle("Effect of personnel on UNOCI's dialogue activities") xtitle("Distance to human rights field offices") 
graph export "./Figures/Figure_exclusionRestriction1.png", replace


margins, at(distHQ = (-1.5(0.5)3.5) civilAffairsPers=(20 27) )  level(95)
marginsplot, recast(line) recastci(rline ) plotopts(lwidth(medthick)) title(" ") ciopts(lpattern(dash dash) lwidth(medthick)) ///
graphregion(fcolor(white))  ///
ytitle("Number of UNOCI's dialogue activities") xtitle("Distance to human rights field office") ///
legend(title("Civilian personnel") label(1 "Minimum") label(2 "Maximum")) legend(order(1 2)) 
graph export "./Figures/Figure_exclusionRestriction2.png", replace










*******************************************************************************
** Appendix C:
** Bivariate probit models of non-communal violence 
** involving government security forces and non-state armed actors
*******************************************************************************


*******************************************************************************
** Bivariate probit models of violence by government actors
*******************************************************************************
set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: govRepression2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3 ), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixC_GovRepression.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
capture drop low
capture drop high
margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
gen estimate = `b'[1,1] in 1
gen low =  `b'[5,1] in 1
gen high = `b'[6,1] in 1


*CEM 
set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: govRepression2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3 ) [iweight = cem_weights], from(coef_start) robust tol(0.01) ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]
matrix coef_start2 = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixC_GovRepression.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 2
replace low =  `b'[5,1] in 2
replace high = `b'[6,1] in 2


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: govRepression2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3 District1-District12) [iweight = cem_weights], from(coef_start2) robust nrtol(0.0001) ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixC_GovRepression.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 3
replace low =  `b'[5,1] in 3
replace high = `b'[6,1] in 3
capture drop x
gen x = 1 in 1
replace x = 2 in 2
replace x = 3 in 3

#delimit ;
twoway scatter estimate x, msize(large) || rcap low high x, yline(0) lcolor(gs0) color(gs0) msize(large)
xscale(range(0.5 3.5)) xlabel(1 `" "Model 7" "Without matching" "' 2 `" "Model 8" "After matching" "' 3 `" "Model 9" "After matching" "+ region dummies" "', labsize(large))
xtitle("")
yscale(range(-0.5 0.1)) ylabel(-0.5 "-0.5" -0.4 "-0.4" -0.3 "-0.3" -0.2 "-0.2" -0.1 "-0.1" 0 "0" 0.1 "0.1")
ytitle("Marginal effect of dialogues" " " , size(large))
scheme(stmono) graphregion(fcolor(white)) lstyle(none)
legend(off);
#delimit cr


*******************************************************************************
** Bivariate probit models of violence involving non-state armed groups
** without explicit communal ties
*******************************************************************************
set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: nsaViolenceNonCommunal2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3 ), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables\AppendixC_NSAViolence.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
capture drop low
capture drop high
capture drop estimate
gen estimate = `b'[1,1] in 1
gen low =  `b'[5,1] in 1
gen high = `b'[6,1] in 1


** CEM
set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: nsaViolenceNonCommunal2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoNsaViolenceNonCommunl  monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3 ) [iweight = cem_weights], from(coef_start) robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start2 = e(b)

#delimit ;
outreg2 [m] using "./Tables\AppendixC_NSAViolence.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 2
replace low =  `b'[5,1] in 2
replace high = `b'[6,1] in 2


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: nsaViolenceNonCommunal2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3 District1-District11) [iweight = cem_weights], robust from(coef_start2) nrtol(0.0001) tol(0.0001) ltol(0.0001);
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]
gen sample = e(sample)

#delimit ;
outreg2 [m] using "./Tables\AppendixC_NSAViolence.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

margins, dydx(reconciliationPublicEvent3Lag2) asobserved predict(p11) force
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 3
replace low =  `b'[5,1] in 3
replace high = `b'[6,1] in 3
capture drop x
gen x = 1 in 1
replace x = 2 in 2
replace x = 3 in 3

#delimit ;
twoway scatter estimate x, msize(large) || rcap low high x, yline(0) lcolor(gs0) color(gs0) msize(large)
xscale(range(0.5 3.5)) xlabel(1 `" "Model 10" "Without matching" "' 2 `" "Model 11" "After matching" "' 3 `" "Model 12" "After matching" "+ region dummies" "', labsize(large))
xtitle("")
yscale(range(-0.5 0.1)) ylabel(-0.5 "-0.5" -0.4 "-0.4" -0.3 "-0.3" -0.2 "-0.2" -0.1 "-0.1" 0 "0" 0.1 "0.1")
ytitle("Marginal effect of dialogues" " " , size(large))
scheme(stmono) graphregion(fcolor(white)) lstyle(none)
legend(off);
#delimit cr





***************************************************************************************************
*** Appendix D: Test for whether the presence of any UN personnel matters more than activity
***************************************************************************************************

*********************
** Communal violence by groups of civilian
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ), vce(cluster Department_num) ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixD_AllPersonnel1.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpersonnel_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


** CEM
set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ) [iweight = cem_weights], robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixD_AllPersonnel1.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpersonnel_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 District1-District12) [iweight = cem_weight], robust from(coef_start) ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixD_AllPersonnel1.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpersonnel_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr




****************************
** Communal violence by  armed actors with communal ties
****************************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3), vce(cluster Department_num) ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixD_AllPersonnel2.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpersonnel_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


** CEM
set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 ) [iweight = cem_weights], from(coef_start) robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixD_AllPersonnel2.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpersonnel_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOpersonnel_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 District1-District12) [iweight = cem_weight], robust tol(0.1) from(coef_start) ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]


#delimit ;
outreg2 [m] using "./Tables/AppendixD_AllPersonnel2.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpersonnel_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr




********************************************************************************************
*** Appendix E: Spatial displacement of violence to districts that are not treated *********
********************************************************************************************

*********************
** Communal violence by groups of civilian
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled  electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 c.publicEevents_spatialLags2##c.NumberNeighbours PKOpolice_scaled PKOtroops_scaled  electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

margins, dydx(publicEevents_spatialLags2) at(NumberNeighbours = (0(1)10) ) force

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixE_SpatialLag.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled c.publicEevents_spatialLags2##c.NumberNeighbours
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 )
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



*********************
** Communal violence by armed actors with communal ties
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled  electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 c.publicEevents_spatialLags2##c.NumberNeighbours PKOpolice_scaled PKOtroops_scaled  electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 ), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

margins, dydx(publicEevents_spatialLags2) at(NumberNeighbours = (0(1)10) ) force

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixE_SpatialLag.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled c.publicEevents_spatialLags2##c.NumberNeighbours
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr




********************************************************************************
** Appendix F Temporal effect of reconciliation ********************************
********************************************************************************

********************************************************************************
** 1 - 3 months ****************************************************************
********************************************************************************

*********************
** Communal violence by groups of civilian
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3), robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_civ_1-3.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3) [iweight=cem_weight], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_civ_1-3.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



*********************
** Communal violence by armed actors with communal ties
*********************
set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3), robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_1-3.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3) [iweight=cem_weight], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_1-3.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



*********************************************************************************
** 4 - 6 months
*********************************************************************************

*********************
** Communal violence by groups of civilian
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent6Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_civ_4-6.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent6Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent6Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent6Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3) [iweight=cem_weight], robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]


capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_civ_4-6.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


*********************
** Communal violence by armed groups with communal ties
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent6Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3), robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_4-6.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent6Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent6Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent6Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3) [iweight=cem_weight], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_4-6.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr




*******************************************************************************
** 7 - 9 months
*******************************************************************************

*********************
** Communal violence by groups of civilian
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent9Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_civ_7-9.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent9Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent9Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent9Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3) [iweight=cem_weight], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

margins, dydx(reconciliationPublicEvent9Lag2) at(reconciliationPublicEvent=0 reconciliationPublicEvent3Lag2=0 reconciliationPublicEvent6Lag2=0) force predict(p11)
margins, dydx(reconciliationPublicEvent9Lag2) at(reconciliationPublicEvent=0 reconciliationPublicEvent3Lag2=0 reconciliationPublicEvent6Lag2=1) force predict(p11)
margins, dydx(reconciliationPublicEvent9Lag2) at(reconciliationPublicEvent=0 reconciliationPublicEvent3Lag2=1 reconciliationPublicEvent6Lag2=0) force predict(p11)

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_civ_7-9.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



*********************
** Communal violence by groups of civilian
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent9Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3), robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_7-9.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent9Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent9Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent9Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3) [iweight=cem_weight], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_7-9.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



********************************************************************************
** 10 - 12 months
********************************************************************************

*********************
** Communal violence by groups of civilian
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent12Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_civ_10-12.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent12Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent12Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent9Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: civViolence2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3) [iweight=cem_weight], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_10-12.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


*********************
** Communal violence by armed groups with communal ties
*********************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent12Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3), robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_10-12.doc", replace
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent12Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent12Lag2)

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent12Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3) [iweight=cem_weight], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

capture matrix drop coef_start
matrix coef_start = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixF_TemporalLag_com_10-12.doc", append
symbol(**, *, +) ctitle("UN") label dec(4)
keep(reconciliationPublicEvent reconciliationPublicEvent3Lag2 reconciliationPublicEvent6Lag2 reconciliationPublicEvent9Lag2 reconciliationPublicEvent12Lag2
 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr







**********************************************
**** Appendix G: Models including UN military and troops saparately 
**********************************************

** Generate interactions and instrument
bysort Year: egen PKOtroops_total = total(PKOtroops)
capture drop pkoPersAll_Troops 
capture drop instrument
capture gen pkoPersAll_Troops = PKOtroops_total
capture gen distHQ = distAbidjan_geo
capture gen instrument_Troops = pkoPersAll_Troops * distHQ 

bysort Year: egen PKOpolice_total = total(PKOpolice)
capture drop pkoPersAll_Police 
capture drop instrument_Police
capture gen pkoPersAll_Police = PKOpolice_total
capture gen distHQ = distAbidjan_geo
capture gen instrument_Police = pkoPersAll_Police * distHQ 


*******************************************************************************
** For effect of troops
*******************************************************************************

*********************************
* Violence by groups of civilian
*********************************
set seed 1234
#delimit ;
biprobit (eq1: PKOtroops2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ), robust ;
#delimit cr

#delimit ;
probit civViolence2 reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3, robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Military_Civ.doc", replace
symbol(**, *, +) ctitle("UN") label 
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


imb competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOtroops2)
cem competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOtroops2)

set seed 1234
#delimit ;
biprobit (eq1: PKOtroops2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOtroops electionMonths competitiveness ttime_mean bdist1 
imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ) [iweight=cem_weight], robust ;
#delimit cr

#delimit ;
probit civViolence2 reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 [iweight=cem_weight], robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Military_Civ.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


**************************************
* Communal violence by armed groups
**************************************
set seed 1234
#delimit ;
biprobit (eq1: PKOtroops2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOtroops2 electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3  ), robust ;
#delimit cr

#delimit ;
probit militiaViolenceCommunalId2 reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 , robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Military_Com.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOtroops_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 )
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

imb competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOtroops2)
cem competitiveness (#5) ttime_mean (#5) bdist1 (#5) imr_mean (#5) Total (#5), tr(PKOtroops2)

/*set seed 1234
#delimit ;
biprobit (eq1: PKOtroops2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 
imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3) [iweight=cem_weight], robust ;
#delimit cr*/

#delimit ;
probit militiaViolenceCommunalId2 reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 [iweight=cem_weight], robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Military_Com.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 )
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

*********************************
* Government violence
*********************************
set seed 1234
#delimit ;
biprobit (eq1: PKOtroops2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: govRepression2 = reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3), robust ;
#delimit cr

#delimit ;
probit govRepression2 reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3, robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Military_Gov.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total 
monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

imb competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOtroops2)
cem competitiveness (#4) ttime_mean (#4) bdist1 (#4) imr_mean (#4) Total (#4), tr(PKOtroops2)

set seed 1234
/*#delimit ;
biprobit (eq1: PKOtroops2 = competitiveness ttime_mean bdist1 imr_mean Total)
(eq2: govRepression2 = reconciliationPublicEvent3Lag2 PKOtroops electionMonths competitiveness ttime_mean bdist1 
imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3) [iweight=cem_weight], robust ;
#delimit cr*/

#delimit ;
probit govRepression2 reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3 [iweight=cem_weight], robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Military_Gov.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



********************************************
* Non-communal violence by armed groups
********************************************
set seed 1234
#delimit ;
biprobit (eq1: PKOtroops2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_T distHQ instrument_T)
(eq2: nsaViolenceNonCommunal2 = reconciliationPublicEvent3Lag2  PKOtroops2 electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ), robust ;
#delimit cr

#delimit ;
probit nsaViolenceNonCommunal2 reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3, robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Military_NSA.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

imb competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOtroops2)
cem competitiveness (#4) ttime_mean (#4) bdist1 (#4) imr_mean (#4) Total (#4) , tr(PKOtroops2)

set seed 1234
/*#delimit ;
biprobit (eq1: PKOtroops2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: nsaViolenceNonCommunal2 = reconciliationPublicEvent3Lag2 PKOtroops electionMonths competitiveness ttime_mean bdist1 
imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3) [iweight=cem_weight], robust ;
#delimit cr */

#delimit ;
probit nsaViolenceNonCommunal2 reconciliationPublicEvent3Lag2 PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3 [iweight=cem_weight], robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Military_NSA.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



*******************************************************************************
** For effect of police
*******************************************************************************

*************************************
* Violence by groups of civilians
*************************************
set seed 1234
#delimit ;
biprobit (eq1: PKOpolice2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOpolice electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 ), robust ;
#delimit cr

#delimit ;
probit civViolence2 reconciliationPublicEvent3Lag2 PKOpolice_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3, robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Police_Civ.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

imb competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOpolice2)
cem competitiveness (#3) ttime_mean (#3) bdist1 (#3) imr_mean (#3) Total (#3), tr(PKOpolice2)

set seed 1234
/*#delimit ;
biprobit (eq1: PKOpolice2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: civViolence2 = reconciliationPublicEvent3Lag2 PKOpolice electionMonths competitiveness ttime_mean bdist1 
imr_mean Total monthsOfNoCivViolence  monthsOfNoCivViolence2  monthsOfNoCivViolence3 ) [iweight=cem_weight], robust ;
#delimit cr*/

#delimit ;
probit civViolence2 reconciliationPublicEvent3Lag2 PKOpolice_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3 [iweight=cem_weight], robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Police_Civ.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled 
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoCivViolence monthsOfNoCivViolence2 monthsOfNoCivViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


*******************************************
* Communal violence by armed groups
*******************************************
set seed 1234
#delimit ;
biprobit (eq1: PKOpolice2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOpolice2 electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 ), robust ;
#delimit cr

#delimit ;
probit militiaViolenceCommunalId2 reconciliationPublicEvent3Lag2 PKOpolice_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3, robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Police_Com.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

imb competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOpolice2)
cem competitiveness (#3) ttime_mean (#3) bdist1 (#3) imr_mean (#3) Total (#3), tr(PKOpolice2)

set seed 1234
#delimit ;
biprobit (eq1: PKOpolice2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: militiaViolenceCommunalId2 = reconciliationPublicEvent3Lag2 PKOpolice2 electionMonths competitiveness ttime_mean bdist1 
imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 ) [iweight=cem_weight], robust ;
#delimit cr

#delimit ;
probit militiaViolenceCommunalId2 reconciliationPublicEvent3Lag2 PKOpolice_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3 [iweight=cem_weight], robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Police_Com.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoMilitiaViolencCmmnlId monthsOfNoMilitiaViolencCmmnlId2 monthsOfNoMilitiaViolencCmmnlId3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


*******************************
* Government violence
*******************************
set seed 1234
#delimit ;
biprobit (eq1: PKOpolice2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: govRepression2 = reconciliationPublicEvent3Lag2 PKOpolice2 electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3 ), robust ;
#delimit cr

#delimit ;
probit govRepression2 reconciliationPublicEvent3Lag2 PKOpolice_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3, robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Police_Gov.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

imb competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOpolice2)
cem competitiveness (#3) ttime_mean (#3) bdist1 (#3) imr_mean (#3) Total (#3), tr(PKOpolice2)

set seed 1234
/*#delimit ;
biprobit (eq1: PKOpolice2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: govRepression2 = reconciliationPublicEvent3Lag2 PKOpolice2 electionMonths competitiveness ttime_mean bdist1 
imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3 ) [iweight=cem_weight], robust ;
#delimit cr*/

#delimit ;
probit govRepression2 reconciliationPublicEvent3Lag2 PKOpolice_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3 [iweight=cem_weight], robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Police_Gov.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoGovRepression monthsOfNoGovRepression2 monthsOfNoGovRepression3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



****************************************
* Non-communal vilence by armed group
****************************************
set seed 1234
#delimit ;
biprobit (eq1: PKOpolice2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: nsaViolenceNonCommunal2 = reconciliationPublicEvent3Lag2 PKOpolice2 electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3 ), robust ;
#delimit cr

#delimit ;
probit nsaViolenceNonCommunal2 reconciliationPublicEvent3Lag2 PKOpolice_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3, robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Police_NSA.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr

imb competitiveness ttime_mean bdist1 imr_mean Total, tr(PKOpolice2)
cem competitiveness (#3) ttime_mean (#3) bdist1 (#3) imr_mean (#3) Total (#2), tr(PKOpolice2)

set seed 1234
/*#delimit ;
biprobit (eq1: PKOpolice2 = competitiveness ttime_mean bdist1 imr_mean Total pkoPersAll_Troops distHQ instrument_Troops)
(eq2: nsaViolenceNonCommunal2 = reconciliationPublicEvent3Lag2 PKOpolice2 electionMonths competitiveness ttime_mean bdist1 
imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3 ) [iweight=cem_weight], robust ;
#delimit cr*/

#delimit ;
probit nsaViolenceNonCommunal2 reconciliationPublicEvent3Lag2 PKOpolice_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3 [iweight=cem_weight], robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

#delimit ;
outreg2 [m] using "./Tables/AppendixG_Police_NSA.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total
monthsOfNoNsaViolenceNonCommunl monthsOfNoNsaViolenceNonCommunl2 monthsOfNoNsaViolenceNonCommunl3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr





*******************************************************************************
** Appendix H: Bivariate probit models of violence involving militia groups
** 				lenient operationalization only excluding criminal groups and AQIM
*******************************************************************************

set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolence2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolence monthsOfNoMilitiaViolence2 monthsOfNoMilitiaViolence3 ), robust ;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start = e(b)
margins, dydx(reconciliationPublicEvent3Lag2) at(reconciliationPublicEvent3Lag2=1) asobserved predict(p11) force level(95)
tempname b
matrix `b' = r(table)
matrix list `b'
capture drop estimate low high
gen estimate = `b'[1,1] in 1
gen low =  `b'[5,1] in 1
gen high = `b'[6,1] in 1


#delimit ;
outreg2 [m] using "./Tables/AppendixH_LenientArmedGrCom.doc", replace
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolence monthsOfNoMilitiaViolence2 monthsOfNoMilitiaViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr



** CEM
set seed 1234
imb PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean imr_mean Total, tr(reconciliationPublicEvent3Lag2) 
cem PKOpolice_scaled PKOtroops_scaled competitiveness bdist1 ttime_mean (#2) imr_mean Total (#2), tr(reconciliationPublicEvent3Lag2)


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolence2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolence  monthsOfNoMilitiaViolence2 monthsOfNoMilitiaViolence3 ) [iweight = cem_weights], from(coef_start) robust;
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]

matrix coef_start2 = e(b)

#delimit ;
outreg2 [m] using "./Tables/AppendixH_LenientArmedGrCom.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolence monthsOfNoMilitiaViolence2 monthsOfNoMilitiaViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


margins, dydx(reconciliationPublicEvent3Lag2) at(reconciliationPublicEvent3Lag2=1) asobserved predict(p11) force level(95)
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 2
replace low =  `b'[5,1] in 2
replace high = `b'[6,1] in 2


set seed 1234
#delimit ;
biprobit (eq1: reconciliationPublicEvent3Lag2 = PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument)
(eq2: militiaViolence2 = reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled electionMonths competitiveness ttime_mean bdist1 imr_mean Total monthsOfNoMilitiaViolence monthsOfNoMilitiaViolence2 monthsOfNoMilitiaViolence3 District1-District11) [iweight = cem_weights], robust from(coef_start2) nrtol(0.0001);
#delimit cr
est store m
estat ic
mat es_ic = r(S)
local AIC: display %4.1f es_ic[1,5]
local BIC: display %4.1f es_ic[1,6]
local LL: display %4.1f es_ic[1,3]
capture gen sample = e(sample)

#delimit ;
outreg2 [m] using "./Tables/AppendixH_LenientArmedGrCom.doc", append
symbol(**, *, +) ctitle("UN") label
keep(reconciliationPublicEvent3Lag2 PKOpolice_scaled PKOtroops_scaled
electionMonths competitiveness ttime_mean bdist1 imr_mean Total civilAffairsPers distHQ instrument
monthsOfNoMilitiaViolence monthsOfNoMilitiaViolence2 monthsOfNoMilitiaViolence3)
addtext(Log-Likelihood, `LL', BIC, `BIC', AIC, `AIC' ) eqkeep(eq1 eq2) ;
#delimit cr


margins, dydx(reconciliationPublicEvent3Lag2) at(reconciliationPublicEvent3Lag2=1) asobserved predict(p11) force level(95)
tempname b
matrix `b' = r(table)
matrix list `b'
replace estimate = `b'[1,1] in 3
replace low =  `b'[5,1] in 3
replace high = `b'[6,1] in 3
capture drop x
gen x = 1 in 1
replace x = 2 in 2
replace x = 3 in 3

#delimit ;
twoway scatter estimate x, msize(large) || rcap low high x, yline(0) lcolor(gs0) color(gs0) msize(large)
xscale(range(0.5 3.5)) xlabel(1 `" "Model 4" "Without matching" "' 2 `" "Model 5" "After matching" "' 3 `" "Model 6" "After matching" "+ region dummies" "', labsize(large))
xtitle("")
yscale(range(-0.05 0.01)) ylabel(-0.05 "-0.05" -0.04 "-0.04" -0.03 "-0.03" -0.02 "-0.02" -0.01 "-0.01" 0 "0" 0.01 "0.01")
ytitle("Marginal effect of dialogues" " " , size(large))
scheme(stmono) graphregion(fcolor(white)) lstyle(none)
legend(off);
#delimit cr

exit



